@@ -3,10 +3,10 @@
 ;; Copyright (C) 1992-2019  Free Software Foundation, Inc.
 
 ;; Author:           Bob Weiner
-;; Maintainer:       Bob Weiner <rsw@gnu.org> and Mats Lidell <matsl@gnu.org>
+;; Maintainer:       Bob Weiner <rsw@gnu.org>, Mats Lidell <matsl@gnu.org>
 ;; Created:          06-Oct-92 at 11:52:51
-;; Released:         21-Jan-19
-;; Version:          7.0.3
+;; Released:         27-Aug-19
+;; Version:          7.0.6
 ;; Keywords:         comm, convenience, files, frames, hypermedia, languages, mail, matching, mouse, multimedia, outlines, tools, wp
 ;; Package:          hyperbole
 ;; Package-Requires: ((emacs "24.4"))
@@ -39,11 +39,11 @@
 ;; 
 ;; 3. Build outlines with multi-level numbered outline nodes, e.g. 1.4.8.6,
 ;; that all renumber automatically as any node or tree is moved in the
-;; outline. Each node also has a permanent hyperlink anchor that you can
+;; outline.  Each node also has a permanent hyperlink anchor that you can
 ;; reference from any other node;
 ;; 
 ;; 4. Manage all your contacts quickly with hierarchical categories and embed
-;; hyperlinks within each entry. Or create an archive of documents with
+;; hyperlinks within each entry.  Or create an archive of documents with
 ;; hierarchical entries and use the same search mechanism to quickly find any
 ;; matching entry;
 ;; 
@@ -54,7 +54,7 @@
 ;; major web search engines with the touch of a few keys.
 ;; 
 ;; The common thread in all these features is making retrieval, management and
-;; display of information fast and easy. That is Hyperbole's purpose.
+;; display of information fast and easy.  That is Hyperbole's purpose.
 ;; 
 ;; ----
 ;;
@@ -74,7 +74,7 @@
 ;;; ************************************************************************
 
 (defconst hyperbole-loading t
-  "Temporary constant available for testing while Hyperbole is loading.") 
+  "Temporary constant available for testing while Hyperbole is loading.")
 
 ;; Ensure defgroup and defcustom are defined for use throughout Hyperbole.
 (require 'custom)
@@ -119,7 +119,7 @@
 				       "hversion"
 				       (file-name-directory load-file-name))
 			    t)))
-    (error "(Hyperbole): Startup failure: `hyperb:dir' must be manually added to `load-path' to fix.")))
+    (error "(Hyperbole): Startup failure: `hyperb:dir' must be manually added to `load-path' to fix")))
 
 ;; This must be defined before the defcustom `inhbit-hyperbole-messaging'.
 ;;;###autoload
@@ -199,7 +199,7 @@ See `hkey-binding-entry' for format.")
 See `hkey-binding-entry' for format.")
 
 (defun hkey-binding-entry (key)
-  "Given an Emacs KEY that may be bound, returns an entry to save the associated binding.
+  "Given an Emacs KEY that may be bound, return an entry to save the associated binding.
 Entry format is: (key-description key-sequence key-binding)."
   (list (key-description key) key (key-binding key)))
 
@@ -207,7 +207,7 @@ Entry format is: (key-description key-sequence key-binding)."
   (mapcar #'cadr entries))
 
 (defun hkey-get-bindings ()
-  "Returns a list of entries for storage of Hyperbole key bindings.
+  "Return a list of entries for storage of Hyperbole key bindings.
 `hkey-initialize' must have already been called or the list will be empty."
   (mapcar (lambda (key) (hkey-binding-entry key))
 	  (hkey-bindings-keys hkey-previous-bindings)))
@@ -253,13 +253,13 @@ Entry format is: (key-description key-sequence key-binding)."
     ;; Binds {C-c @} to created a user-specified sized grid of windows
     ;; displaying different buffers.
     ;;
-    ;; Don't override local bindings of this key.
+    ;; Don't override prior global bindings of this key.
     (hkey-maybe-global-set-key "\C-c@" 'hycontrol-windows-grid t)
     ;;
     ;; Binds {C-c C-r} as a site standard way of performing explicit
     ;; button renames without invoking the Hyperbole menu.
     ;;
-    ;; Don't override local bindings of this key.
+    ;; Don't override prior global bindings of this key.
     (hkey-maybe-global-set-key "\C-c\C-r" 'hui:ebut-rename t)
     ;;
     ;; Binds {C-c RET} to select larger and larger synctactical units in a
@@ -274,7 +274,7 @@ Entry format is: (key-description key-sequence key-binding)."
     (hkey-maybe-global-set-key "\C-c/" 'hui-search-web)
     ;;
     ;; Binds {C-c .} to jump between the start and end of an delimited thing.
-    ;; Don't override local bindings of this key.
+    ;; Don't override prior global bindings of this key.
     (hkey-maybe-global-set-key "\C-c." 'hui-select-goto-matching-delimiter t)
     ;;
     ;; This initializes the Smart Mouse Key bindings.  Shifted mouse buttons
@@ -300,7 +300,7 @@ With third argument NO-ADD non-nil, skip storage of prior KEY binding
 which prevents automatic removal of any local bindings to the same key."
   (or (global-key-binding key)
       (where-is-internal command)
-      (hkey-global-set-key key command)))
+      (hkey-global-set-key key command no-add)))
 
 (defun hkey-set-bindings (key-binding-list)
   "Set keys bound by Hyperbole to those in KEY-BINDING-LIST.
@@ -311,7 +311,7 @@ bindings after load)."
      (global-set-key (cadr key-and-binding) (car (cddr key-and-binding)))))
 
 (defun hyperbole-toggle-bindings ()
-  "Toggles between Hyperbole mouse and keyboard keys and their prior bindings."
+  "Toggle between Hyperbole mouse and keyboard keys and their prior bindings."
   (interactive)
   (let ((key-binding-list (if hkey-bindings-flag
 			      hkey-previous-bindings
@@ -328,7 +328,7 @@ bindings after load)."
 	  (if (called-interactively-p 'interactive)
 	      (message "%s mouse and keyboard bindings are now in use."
 		       (if hkey-bindings-flag "Hyperbole" "Non-Hyperbole"))))
-      (error "(hyperbole-toggle-bindings): `%s' is empty."
+      (error "(hyperbole-toggle-bindings): `%s' is empty"
 	     (if hkey-bindings-flag 'hkey-previous-bindings 'hkey-bindings)))))
 
 ;;; ************************************************************************
@@ -456,7 +456,7 @@ With optional ARG, override them iff ARG is positive."
 ;; the Hyperbole package is activated in an Emacs session.
 ;;;###autoload (load "kotl/kotl-autoloads" nil 'nowarn)
 
-;; Before the 6.0.1 release, Hyperbole used to patch the package-generate-autoloads 
+;; Before the 6.0.1 release, Hyperbole used to patch the package-generate-autoloads
 ;; function to ensure that kotl/ subdirectories were autoloaded.  This
 ;; is no longer used but is left here temporarily for reference.
 ;;
@@ -516,7 +516,7 @@ With optional ARG, override them iff ARG is positive."
 ;;   "Creates implicit button TYPE (unquoted sym) with PARAMS, described by DOC."
 ;;   nil 'macro)
 
-;; (autoload 'ebut:map          "hyperbole"      "Map over Hyperbole buffer buttons." nil)
+;; (autoload 'ebut:map          "hyperbole"      "Map over the Hyperbole explicit buttons in a buffer." nil)
 ;; (autoload 'hbut:key-src      "hyperbole"      "Called by {e} command in rolo match buffer.")
 ;; (autoload 'hui:ebut-rename   "hyperbole"      "Rename a Hyperbole button."     t)
 ;; (autoload 'hyperbole         "hyperbole"      "Hyperbole info manager menus."  t)
@@ -698,7 +698,7 @@ If FLAG is nil then text is shown, while if FLAG is t the text is hidden."
       (hkey-install-override-local-bindings)
     (add-hook 'after-load-alist '(hyperbole hkey-install-override-local-bindings)))
   ;;
-  ;; Hyperbole initialization is complete. 
+  ;; Hyperbole initialization is complete.
   (message "Initializing Hyperbole...done")
   (message "Hyperbole %s is ready for action." hyperb:version))
 
